# Moved: SPEC-QUALITY-140_ml_enhanced_quality_optimization.md

This specification has moved to:

- [domains/quality/SPEC-QUALITY-140_ml_enhanced_quality_optimization.md](./domains/quality/SPEC-QUALITY-140_ml_enhanced_quality_optimization.md)

Note: This is a redirect stub to preserve existing links.
